//+------------------------------------------------------------------+
//|                                                  FrelExample.mq5 |
//|                                  Copyright 2024, MetaQuotes Ltd. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2024, MetaQuotes Ltd."
#property link      "https://www.mql5.com"
#property version   "1.00"
#property script_show_inputs
#include<frel.mqh>

//---user adjustable input parameters
input int number_of_partitions = 8; //Number of partitions
input double regularization_factor = 0.0; //Regularization factor
input int number_of_bootstraps = 1;
input int bootstrap_size = 0;
input ulong num_observations = 2000;// Sample size of random dataset
input ulong num_candidate_predictors = 10;// Maximum number of candidate predictors in dataset
//+------------------------------------------------------------------+
//| Script program start function                                    |
//+------------------------------------------------------------------+
void OnStart()
  {
   srand(126);
//---check user input parameters
   if(number_of_partitions<2 || num_observations<10 || num_candidate_predictors<8)
     {
      Print("Invalid input parameters");
      return;
     }  
//---the data
   matrix dataset;   
//---initialize size of random dataset   
   dataset.Init(num_observations,num_candidate_predictors+1);
//---fill dataset with random data  
   dataset.Random(1.0,10.0);
//---set the target variable in the last column      
   if(!dataset.Col(dataset.Col(1) + dataset.Col(3) + dataset.Col(5) + dataset.Col(7),num_candidate_predictors))
      {
       Print( "error ", GetLastError());
       return;
      }
//---initialize Frel object     
   FREL frel(dataset,number_of_bootstraps,bootstrap_size);
//---declare containers to recieve output from Frel operation   
   double optimal_weights[];
   int index[];
//---   
   ulong timeIT = GetTickCount64();
//---find the most relevant predictors     
   if(!frel.WeighVars(number_of_partitions,regularization_factor,index,optimal_weights))
      return;
//---calculate runtime
   Print("Runtime of FREL ", GetTickCount64() - timeIT, " ms");       
//---display results  
   for(uint i = 0; i<optimal_weights.Size(); i++)
       Print("Predictor at Column index ", index[i], " weight ", optimal_weights[i]);
  
  }
//+------------------------------------------------------------------+
